/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:46+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Albanian (http://www.transifex.com/tine20/tine20/language/sq/)\nLanguage: sq\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "ImportExportDefinition, ImportExportDefinitions"
: [
  ""
 ,""

]
, "Application, Applications"
: [
  "Aplikacion"
 ,"Apliakcione"

]
, "User, Users"
: [
  "Përdorues"
 ,"Përdoruesa"

]
, "Groups"
: "Grupe"

, "Roles"
: "Role"

, "Applications"
: "Aplikacione"

, "Containers"
: "Konteinerë"

, "Shared Tags"
: "Etiketa të ndara"

, "Customfields"
: "Fusha‎ të personifikuara"

, "Computers"
: "Kompjutera"

, "Access Log, Access Logs"
: [
  "Ditari i hyrjeve"
 ,"Ditarët e hyrjeve"

]
, "Log"
: ""

, "Server Information"
: "Informacion i serverit"

, "ActiveSync Devices"
: ""

, "E-mail Accounts"
: ""

, "Import Export Definitions"
: ""

, "Admin"
: "Admin"

, "Refresh"
: "Rifresko"

, "Disabled"
: ""

, "Feature is disabled by configuration."
: ""

, "Default Addressbook for new contacts and groups"
: "Blloku i paracaktuar i adresave për kontakte dhe grupe te rinj"

, "Computer Name"
: "Emri i Kompjuterit"

, "Config, Configs"
: [
  ""
 ,""

]
, "Description"
: "Përshkrimi"

, "Name"
: "Emri"

, "Label"
: "EtiketV"

, "Value"
: "Vlera"

, "Default ({0})"
: ""

, "Yes"
: ""

, "No"
: ""

, "Group Name"
: "Emër Grupi"

, "Visibility"
: "Dukshmëria"

, "Display in addressbook"
: "Shfaqni në bllokun e adresave"

, "Hide from addressbook"
: "Fshihni nga blloku i adresave"

, "Saved in Addressbook"
: "U ruajt në bllokun e adresave"

, "E-mail"
: ""

, "Only system accounts can be added to Addressbook group"
: ""

, "Group Members"
: "Pjesëtarë  Grupi"

, "Domain is not allowed. Check your SMTP domain configuration."
: "Domain nuk lejohet, Kontrolloni konfigurimet e domain-it SMTP"

, "Confirm"
: "Konfirmo"

, "Do you really want to delete the selected tags?"
: "Doni vërtet të fshini etiketat e zgjedhura"

, "Deleting tag(s)..."
: "Duke fshirë etiketën(at)"

, "Add Tag"
: "Shto Etiketë"

, "Edit Tag"
: "Modifiko Etiketën"

, "Delete Tag"
: "Fshij Etiketën"

, "Search:"
: "Kërko:"

, "Displaying tags {0} - {1} of {2}"
: "Duke shfaqur etiketat {0} - {1} nga {2}"

, "No tags to display"
: "Nuk ka etiketa për tu shfaqur"

, "ID"
: "ID"

, "Color"
: "Ngjyrë"

, "Usage:&#160;"
: "Përdorimi:&#160;"

, "Do you really want to delete the selected roles?"
: "Doni vërtetë të fshini rolet e zgjedhur?"

, "Deleting role(s)..."
: "Duke fshirë rolin(et)"

, "Failed"
: "Dështoi"

, "Some error occurred while trying to delete the role."
: "Ndodhën disa gabime ndërkohe që po fshihej roli"

, "Add Role"
: "Shto Rol"

, "Edit Role"
: "Modifiko Rolin"

, "Delete Role"
: "Fshij Rolin"

, "Displaying roles {0} - {1} of {2}"
: "Duke shfaqur rolin {0} - {1} nga {2}"

, "No roles to display"
: "Nuk ka role për tu shfaqur"

, "Container Name"
: "Emri i Konteinerit"

, "Type"
: "Tipi"

, "Container Order"
: ""

, "Container, Containers"
: [
  "Konteiner"
 ,"Konteinerë"

]
, "Model"
: "Modeli"

, "personal"
: "personal"

, "shared"
: "ndarë"

, "Order"
: "Renditje"

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: "Shënim për zoteruesin"

, "Info"
: ""

, "Please create Resources in Addressbook or CoreData."
: ""

, "Do you really want to delete the selected groups?"
: "Doni vërtet të fshini grupet e zgjedhur?"

, "Deleting group(s)..."
: "Duke fshirë grup(et)..."

, "Some error occurred while trying to delete the group."
: "Ndodhën disa gabime ndërkohe që po fshihej grupi"

, "Add Group"
: "Shto Grup"

, "Edit Group"
: "Modifiko Grupin"

, "Delete Group"
: "Fshij Grupin"

, "Displaying groups {0} - {1} of {2}"
: "Duke shfaqur grupet {0} - {1} nga {2}"

, "No groups to display"
: "Nuk ka grupe për tu shfaqur"

, "Account only"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "IP Address"
: "Adresa IP"

, "Login Time"
: "Koha e hyrjes"

, "Logout Time"
: "Koha e daljes"

, "Client Type"
: "Tipi i Klientit"

, "Session ID"
: "ID e seances"

, "Login Name"
: "Emri i Hyrjes"

, "Result"
: "Reziltati"

, "User Agent"
: ""

, "user blocked"
: "përdoruesi i bllokuar"

, "password expired"
: "fjalëkalimi ka skaduar"

, "user disabled"
: "përdoruesi i ç'aktivizuar"

, "invalid password"
: "fjalëkalim jo i saktë"

, "ambiguous username"
: "Emër përdoruesi jo i qartë"

, "user not found"
: "përdouresi nuk u gjend"

, "failure"
: "dështim"

, "success"
: "sukses"

, "Customfield, Customfields"
: [
  "Fushë e personalizuar"
 ,"Fusha të personalizuara"

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Errors"
: "Gabime"

, "Please configure store for this field type"
: "Ju lutem konfiguroni vend-ruajtien për këtë tip fushe"

, "Record Class"
: "Klasa regjistrimit"

, "Given record class not found"
: "Klasa e dhëne e regjistrimit nuk u gjet"

, "Cancel"
: "Anullo"

, "OK"
: "OK"

, "Configure store"
: "Konfiguro vend-ruajtien"

, "Custom field definition"
: "Përcaktimi i fushës së personalizuar"

, "Text"
: "Tekst"

, "Textarea"
: ""

, "Number"
: "Numër"

, "Date"
: "Datë"

, "DateTime"
: "DatëKohë"

, "Time"
: "Kohë"

, "Boolean"
: "Boolean"

, "Search Combo"
: "Kërkim Combo"

, "Key Field"
: "Fusha e Çelësit"

, "Record"
: "E dhënë"

, "Record List"
: ""

, "Length"
: "Gjatësi"

, "Required"
: "Kërkohet"

, "Custom field additional properties"
: "Të dhëna shtesë për fushat e personalizuara"

, "Tab Panel"
: ""

, "Group, Groups"
: [
  "Grup"
 ,"Grupe"

]
, "Key"
: ""

, "Customfield already exists. Please choose another name."
: "Fusha e personalizuar ekziston. Ju lutem zgjidhni një emër tjetër"

, "Enable Account"
: "Aktivizoni Llogarinë"

, "Disable Account"
: "Ç'aktivizoni Llogarinë"

, "Reset Password"
: "Rivendosni Fjalëkalimin"

, "Status"
: "Status"

, "Display name"
: "Emri i Shfaqur"

, "Login name"
: "Emrii Hyrjes"

, "Last name"
: "Mbiemri"

, "First name"
: "Emri"

, "E-mail usage"
: ""

, "Filesystem usage"
: ""

, "OpenID"
: "OpenID"

, "Last login at"
: "Hyrja e fundit më"

, "Last login from"
: "Hyrja e fundit nga"

, "Password Must Change"
: "Fjalëkalimi Duhet ndryshuar"

, "Password changed"
: "Fjalëkalimi ndryshoi"

, "Expires"
: "Skadon"

, "Set new password"
: "Vendosni Fjalëkalimin e ri"

, "Please enter the new password:"
: "Ju lutem fusni fjalëkalimin e ri"

, "Users"
: "Përdorues"

, "Samba User, Samba Users"
: [
  "Perdorues Samba"
 ,"Perdorues Samba"

]
, "Email User, Email Users"
: [
  "Përdorues E-Poste"
 ,"Perdorues E-Poste"

]
, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: "Fjalëkalimet nuk përkojne"

, "Passwords match!"
: "Fjalëkalimet përkojne"

, "Primary group"
: "Grupi primar"

, "Unix"
: "Unix"

, "Home Directory"
: "Skedari Kryesor"

, "Login Shell"
: "Hapësira Hyrjes"

, "Windows"
: "Windows"

, "Home Drive"
: "Arkiva Kryesore"

, "never logged in"
: "Nuk ka hyrë asnjëhere"

, "Home Path"
: "Rruga kryesore"

, "never logged off"
: "Nuk ka dalë asnjëhere"

, "Profile Path"
: "Rruga e profilit"

, "Password Last Set"
: "Fjalëkalimi i funidit i vendosur më"

, "never"
: "asnjëhere"

, "Logon Script"
: "Shkrimi i hyrjes"

, "Password Can Change"
: "Fjalëkalimi mund të ndryshojë"

, "not set"
: "nuk është vendosur"

, "Kick Off Time"
: "Koha e përjashtimit"

, "Filesystem Quota"
: ""

, "Quota"
: "Kuota"

, "no quota set"
: "nuk është vendosur kuotë"

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: "Madhësia aktuale e Kutisë së Postës"

, "Sieve Quota"
: ""

, "Current Sieve size"
: "Madhësia aktuale e Sieve"

, "Information"
: "Informacion"

, "Last Login"
: "Hyrja e Fundit"

, "Forward Only"
: "Vetëm Ridrejtim"

, "E-mail Alias"
: ""

, "Add an alias address..."
: "Shtoni një pseudonim adrese..."

, "This alias can be used for sending e-mails."
: ""

, "Domain not allowed"
: "Domain nuk lejohet"

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "Forwarding to self"
: "Ridrejtuar tek vetja"

, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
: ""

, "E-mail Forward"
: ""

, "Add a forwarding address..."
: ""

, "Password confirmation"
: "Konfirmim Fjalëkalimi"

, "Repeat password"
: "Përsërisni Fjalëkalimin"

, "Ok"
: "OK"

, "Account"
: "Llogari"

, "Password"
: "Fjalëkalimi"

, "Multi Factor Authentication Config"
: ""

, "enabled"
: "aktivizuar"

, "disabled"
: "ç'aktivizuar"

, "expired"
: "skaduar"

, "blocked"
: "bllokuar"

, "Invalid Status"
: "Status i Gabuar"

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: "Statusi i bllokuar është i vlefshëm vetëm nëse përdoruesi provoi të hynte shumë shpeshme fjalëkalim të gabuar. Nuk është e mundur të vendoset ky status këtu"

, "don't know"
: "nuk e di"

, "Password set"
: "Fjalëkalimi u vendos"

, "User groups"
: "Grupet e përdoruesëve"

, "User roles"
: "Rolet e përdoruesëve"

, "Fileserver"
: "Serveri Skedarëve"

, "Filesystem"
: ""

, "IMAP"
: "IMAP"

, "SMTP"
: "SMTP"

, "Computer, Computers"
: [
  "Kompjuter"
 ,"Kompjutera"

]
, "Please wait"
: "Ju lutem prisni"

, "Updating Memberships"
: "Duke përditësuar Anëtarësimet"

, "Could not save role."
: "Roli nuk u ruajt dot"

, "Please fix the errors noted."
: "Ju lutem riparoni gabimet e shënuara"

, "Deleting role..."
: "Duke fshir rolin..."

, "Rights"
: "Të drejta"

, "Members"
: "Pjesëtarë"

, "Role Name"
: "Emri i Rolit"

, "Transferring {0}..."
: "Duke transferuar {0}... "

, "Role"
: "Roli"

, "Add New Role"
: "Shto një rol të ri"

, "Edit Role \"{0}\""
: "Modifiko Rolin \"{0}\""

, "Configs"
: ""

, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Updating Tag"
: "Duke përditesuar etiketën"

, "Could not save tag ({0})"
: ""

, "Allowed Contexts"
: "Kontekst i lejuar"

, "Context"
: "Kontekst"

, "Account Rights"
: "Të drejtat e llogarisë"

, "View"
: "Shiko"

, "Use"
: "Përdor"

, "Tag Name"
: "Emri i Etiketës"

, "Tag"
: "Etiketë"

, "Add New Tag"
: "Shto një etiketë të re"

, "Edit Tag \"{0}\""
: "Modifiko Etiketen \"{0}\""

, "Enable Application"
: "Aktivizo Aplikacionin"

, "Disable Application"
: "Ç'aktivizo Aplikacionin"

, "Settings"
: "Konfigurime"

, "{0} Settings"
: "{0} Konfigurime"

, "Enabled"
: ""

, "Unknown status ({0})"
: ""

, "Displaying application {0} - {1} of {2}"
: "Duke shfaqur aplikacionin  {0} - {1} nga {2}"

, "No applications to display"
: "Nuk ka aplikacione për tu shfaqur"

, "Version"
: "Versioni"

, "Default password must change for new user settings"
: ""

, "Default IMAP user settings"
: "Konfigurimet e Paracaktuara IMAP të përdoruesit"

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "Your container has been changed"
: "Konteineri Juaj është ndryshuar"

, "Your container has been changed by %1$s %2$sNote: %3$s"
: "Konteineri juaj është ndryshuar nga %1$s %2$sShenim: %3$s"

, "Password is needed for system account creation"
: ""

, "Notifications"
: ""

, "Manage access log"
: ""

, "Delete access log entries."
: ""

, "Manage accounts"
: ""

, "Add and edit users and groups, add group members, change user passwords."
: ""

, "Manage e-mail accounts"
: ""

, "Add and edit shared and personal e-mail accounts."
: ""

, "Manage applications"
: ""

, "Enable and disable applications, edit application settings."
: ""

, "Manage roles"
: ""

, "Add and edit roles, add new members to roles, add application rights to roles."
: ""

, "Manage shared tags"
: ""

, "Add, delete and edit shared tags."
: ""

, "Manage computers"
: ""

, "Add, delete and edit (samba) computers."
: ""

, "Manage containers"
: ""

, "Add, delete and edit containers and manage container grants."
: ""

, "Manage customfields"
: ""

, "Add and edit customfields."
: ""

, "Manage import and export definitions"
: ""

, "Add and edit import and export definitions"
: ""

, "View access log"
: ""

, "View access log list."
: ""

, "View accounts"
: ""

, "View accounts list and details."
: ""

, "View e-mail accounts"
: ""

, "View shared and personal e-mail accounts."
: ""

, "View applications"
: ""

, "View applications list and details."
: ""

, "View roles"
: ""

, "View roles list and details."
: ""

, "View shared tags"
: ""

, "View shared tags list and details."
: ""

, "View computers"
: ""

, "View computers list and details."
: ""

, "View containers"
: ""

, "View personal and shared containers."
: ""

, "View customfields"
: ""

, "View customfields list."
: ""

, "View serverinfo"
: ""

, "View serverinfo list."
: ""

, "View quota usage"
: ""

, "View quota usage."
: ""

, "view ImportExportDefinitions"
: ""












































, "ImportExportDefinition"
: ""

, "Application"
: "Aplikacion"

, "User"
: "Përdorues"

, "Access Log"
: "Ditari i hyrjeve"

, "Config"
: ""

, "Container"
: "Konteiner"

, "Customfield"
: "Fushë e personalizuar"

, "Group"
: "Grup"

, "Samba User"
: "Perdorues Samba"

, "Email User"
: "Përdorues E-Poste"

, "Computer"
: "Kompjuter"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
